# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-06 12:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0034_auto_20170921_1535'),
    ]

    operations = [
        migrations.AddField(
            model_name='productfinal',
            name='sample',
            field=models.BooleanField(default=False, help_text='If this option is checked the product can not be sold', verbose_name='Sample'),
        ),
    ]
