# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-01 10:56
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0030_productfinaloption_productfinaloptiontexten_productfinaloptiontextes'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='product',
            name='recargo_equivalencia',
        ),
        migrations.AddField(
            model_name='productfinal',
            name='price_base',
            field=models.FloatField(default=0, editable=False, verbose_name='Price base'),
        ),
        migrations.AddField(
            model_name='typetax',
            name='recargo_equivalencia',
            field=models.FloatField(default=0, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)], verbose_name='Recargo de equivalencia (%)'),
            preserve_default=False,
        ),
    ]
