# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-02 12:01
from __future__ import unicode_literals

import codenerix.fields
import codenerix.lib.helpers
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0024_auto_20170802_0955'),
    ]

    operations = [
        migrations.CreateModel(
            name='PackImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('name_file', models.CharField(blank=True, max_length=254, null=True, verbose_name='Name')),
                ('order', models.SmallIntegerField(blank=True, null=True, verbose_name='Order')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('principal', models.BooleanField(default=False, verbose_name='Principal')),
                ('pack', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='packs_image', to='codenerix_products.Pack', verbose_name='Pack')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackImageTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('pack_image', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.PackImage')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackImageTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('description', models.CharField(max_length=250, verbose_name='Description')),
                ('pack_image', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.PackImage')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='productimagecreate',
            name='temporal_A',
            field=models.BooleanField(default=False, verbose_name='Tmp'),
        ),
        migrations.AddField(
            model_name='productimagecreatemodal',
            name='temporal_B',
            field=models.BooleanField(default=False, verbose_name='Tmp'),
        ),
        migrations.AddField(
            model_name='productimageupdate',
            name='temporal_C',
            field=models.BooleanField(default=False, verbose_name='Tmp'),
        ),
        migrations.AddField(
            model_name='productimageupdatemodal',
            name='temporal_D',
            field=models.BooleanField(default=False, verbose_name='Tmp'),
        ),
        migrations.RemoveField(
            model_name='productimagecreatemodal',
            name='productimagecreate_ptr',
        ),
        migrations.RemoveField(
            model_name='productimageupdatemodal',
            name='productimageupdate_ptr',
        ),
        migrations.RemoveField(
            model_name='productimagecreate',
            name='productimage_ptr',
        ),
        migrations.RemoveField(
            model_name='productimageupdate',
            name='productimage_ptr',
        ),
        migrations.DeleteModel(
            name='ProductImageCreate',
        ),
        migrations.DeleteModel(
            name='ProductImageCreateModal',
        ),
        migrations.DeleteModel(
            name='ProductImageUpdate',
        ),
        migrations.DeleteModel(
            name='ProductImageUpdateModal',
        ),
    ]
