# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-19 11:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0008_category_order'),
    ]

    operations = [
        migrations.AddField(
            model_name='brand',
            name='show_menu',
            field=models.BooleanField(default=True, verbose_name='Show menu'),
        ),
    ]
