# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-10-19 11:10
from __future__ import unicode_literals

import codenerix.fields
import codenerix.lib.helpers
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0037_auto_20171018_1007'),
    ]

    operations = [
        migrations.AddField(
            model_name='family',
            name='icon',
            field=codenerix.fields.ImageAngularField(blank=True, help_text='Se aconseja que sea una imagen superior a 200px transparente y en formato png o svg', max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Icon'),
        ),
    ]
