# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-12 09:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0007_productfinalimage_productfinalimagetexten_productfinalimagetextes'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='order',
            field=models.SmallIntegerField(blank=True, null=True, verbose_name='Order'),
        ),
    ]
