# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-03 14:38
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0026_packoption_order'),
    ]

    operations = [
        migrations.AddField(
            model_name='pack',
            name='order',
            field=models.SmallIntegerField(blank=True, null=True, verbose_name='Order'),
        ),
        migrations.AddField(
            model_name='pack',
            name='tax',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='packs', to='codenerix_products.TypeTax', verbose_name='Tax'),
        ),
    ]
