# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-21 13:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0033_auto_20170921_1206'),
    ]

    operations = [
        migrations.AlterField(
            model_name='brandtexten',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='brandtextes',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='productfinaltexten',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='productfinaltextes',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='producttexttexten',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='producttexttextes',
            name='public',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
    ]
