# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-01 17:19
from __future__ import unicode_literals

import codenerix.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0022_typetax_default'),
    ]

    operations = [
        migrations.CreateModel(
            name='Pack',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('code', models.CharField(blank=True, max_length=250, null=True, unique=True, verbose_name='Code')),
                ('public', models.BooleanField(default=True, verbose_name='Public')),
                ('show_menu', models.BooleanField(default=True, verbose_name='Show menu')),
                ('price', models.FloatField(verbose_name='Price')),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='packs', to='codenerix_products.Category', verbose_name='Category')),
                ('family', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='packs', to='codenerix_products.Family', verbose_name='Family')),
                ('subcategory', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='packs', to='codenerix_products.Subcategory', verbose_name='Subcategory')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackOption',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('active', models.BooleanField(default=True, verbose_name='Active')),
                ('pack', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pack_options', to='codenerix_products.Pack', verbose_name='Pack Option')),
                ('products', models.ManyToManyField(related_name='pack_options', to='codenerix_products.ProductFinal')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackOptionTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('packoption', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.PackOption')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackOptionTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('packoption', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.PackOption')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('pack', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Pack')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PackTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(max_length=250, unique=True, verbose_name='Name')),
                ('description', codenerix.fields.WysiwygAngularField(verbose_name='Description')),
                ('pack', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Pack')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
