# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-03 15:40
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0028_auto_20170803_1446'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pack',
            name='category',
        ),
        migrations.RemoveField(
            model_name='pack',
            name='family',
        ),
        migrations.RemoveField(
            model_name='pack',
            name='subcategory',
        ),
        migrations.RemoveField(
            model_name='pack',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='packimage',
            name='pack',
        ),
        migrations.RemoveField(
            model_name='packimagetexten',
            name='pack_image',
        ),
        migrations.RemoveField(
            model_name='packimagetextes',
            name='pack_image',
        ),
        migrations.RemoveField(
            model_name='packoption',
            name='pack',
        ),
        migrations.RemoveField(
            model_name='packoption',
            name='products',
        ),
        migrations.RemoveField(
            model_name='packoptiontexten',
            name='packoption',
        ),
        migrations.RemoveField(
            model_name='packoptiontextes',
            name='packoption',
        ),
        migrations.RemoveField(
            model_name='packtexten',
            name='pack',
        ),
        migrations.RemoveField(
            model_name='packtextes',
            name='pack',
        ),
        migrations.DeleteModel(
            name='Pack',
        ),
        migrations.DeleteModel(
            name='PackImage',
        ),
        migrations.DeleteModel(
            name='PackImageTextEN',
        ),
        migrations.DeleteModel(
            name='PackImageTextES',
        ),
        migrations.DeleteModel(
            name='PackOption',
        ),
        migrations.DeleteModel(
            name='PackOptionTextEN',
        ),
        migrations.DeleteModel(
            name='PackOptionTextES',
        ),
        migrations.DeleteModel(
            name='PackTextEN',
        ),
        migrations.DeleteModel(
            name='PackTextES',
        ),
    ]
