# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-31 07:54
from __future__ import unicode_literals

import codenerix.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0005_remove_product_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='BrandTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BrandTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('meta_title', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title')),
                ('meta_description', models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description')),
                ('description_short', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description short')),
                ('description_long', codenerix.fields.WysiwygAngularField(blank=True, null=True, verbose_name='Description long')),
                ('slug', models.CharField(max_length=250, unique=True, verbose_name='Slug')),
                ('name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Name')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.RemoveField(
            model_name='brand',
            name='name',
        ),
        migrations.RemoveField(
            model_name='brand',
            name='slug',
        ),
        migrations.AddField(
            model_name='brandtextes',
            name='brand',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_products.Brand'),
        ),
        migrations.AddField(
            model_name='brandtexten',
            name='brand',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_products.Brand'),
        ),
    ]
