# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 08:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0011_groupvalueattribute_groupvaluefeature_groupvaluefeaturespecial_optionvalueattribute_optionvaluefeatu'),
    ]

    operations = [
        migrations.AddField(
            model_name='attribute',
            name='list_value_new',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='attributes', to='codenerix_products.GroupValueAttribute', verbose_name='List value'),
        ),
        migrations.AddField(
            model_name='feature',
            name='list_value_new',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='features', to='codenerix_products.GroupValueFeature', verbose_name='List value'),
        ),
        migrations.AddField(
            model_name='featurespecial',
            name='list_value_new',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='feature_specials', to='codenerix_products.GroupValueFeatureSpecial', verbose_name='List value'),
        ),
    ]
