# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-07-17 10:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0021_subcategory_show_brand'),
    ]

    operations = [
        migrations.AddField(
            model_name='typetax',
            name='default',
            field=models.BooleanField(default=False, verbose_name='Default'),
        ),
    ]
