# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-08 15:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0040_auto_20171107_1013'),
    ]

    operations = [
        migrations.AddField(
            model_name='brandtexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='brandtextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='categorytexten',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='categorytexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='categorytexten',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='categorytextes',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='categorytextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='categorytextes',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='familytexten',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='familytexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='familytexten',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='familytextes',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='familytextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='familytextes',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontexten',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontexten',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontextes',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='productfinaloptiontextes',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='productfinaltexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='productfinaltextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='producttexttexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='producttexttextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='subcategorytexten',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='subcategorytexten',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='subcategorytexten',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AddField(
            model_name='subcategorytextes',
            name='meta_description',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Description'),
        ),
        migrations.AddField(
            model_name='subcategorytextes',
            name='meta_keywords',
            field=models.CharField(blank=True, max_length=160, null=True, verbose_name='Meta Keywords'),
        ),
        migrations.AddField(
            model_name='subcategorytextes',
            name='meta_title',
            field=models.CharField(blank=True, max_length=70, null=True, verbose_name='Meta Title'),
        ),
        migrations.AlterField(
            model_name='attribute',
            name='type_price',
            field=models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price'),
        ),
        migrations.AlterField(
            model_name='attribute',
            name='type_value',
            field=models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value'),
        ),
        migrations.AlterField(
            model_name='feature',
            name='type_price',
            field=models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price'),
        ),
        migrations.AlterField(
            model_name='feature',
            name='type_value',
            field=models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value'),
        ),
        migrations.AlterField(
            model_name='featurespecial',
            name='type_price',
            field=models.CharField(choices=[('P', 'Porcentaje sobre el precio del producto'), ('I', 'Incremento sobre el precio del producto'), ('F', 'Precio final')], default='P', max_length=2, verbose_name='Type price'),
        ),
        migrations.AlterField(
            model_name='featurespecial',
            name='type_value',
            field=models.CharField(choices=[('F', 'Sin validacion'), ('B', 'Boolean'), ('O', 'Lista de opciones')], default='F', max_length=2, verbose_name='Type value'),
        ),
        migrations.AlterField(
            model_name='flagshipproduct',
            name='orientazion',
            field=models.CharField(choices=[('R', 'Right'), ('L', 'Left')], default='R', max_length=2, verbose_name='Orientazion'),
        ),
    ]
