# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-07 10:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0003_auto_20170307_1027'),
    ]

    operations = [
        migrations.AlterField(
            model_name='productfeature',
            name='value',
            field=models.CharField(max_length=80, verbose_name='Value'),
        ),
    ]
