# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-03 14:46
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0027_auto_20170803_1438'),
    ]

    operations = []
