# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-03 08:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='productfinal',
            name='reviews_count',
            field=models.IntegerField(default=0, editable=False, verbose_name='Reviews count'),
        ),
        migrations.AddField(
            model_name='productfinal',
            name='reviews_value',
            field=models.FloatField(default=0, editable=False, verbose_name='Reviews'),
        ),
    ]
