# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 11:42
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0015_auto_20170505_1141'),
    ]

    operations = [
        migrations.RenameField(
            model_name='attribute',
            old_name='list_value_new',
            new_name='list_value',
        ),
        migrations.RenameField(
            model_name='feature',
            old_name='list_value_new',
            new_name='list_value',
        ),
        migrations.RenameField(
            model_name='featurespecial',
            old_name='list_value_new',
            new_name='list_value',
        ),
    ]
