# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 11:41
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0014_migrate_group_value'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='optionvaluetexten',
            name='option_value',
        ),
        migrations.RemoveField(
            model_name='optionvaluetextes',
            name='option_value',
        ),
        migrations.RemoveField(
            model_name='attribute',
            name='list_value',
        ),
        migrations.RemoveField(
            model_name='feature',
            name='list_value',
        ),
        migrations.RemoveField(
            model_name='featurespecial',
            name='list_value',
        ),
        migrations.DeleteModel(
            name='OptionValueTextEN',
        ),
        migrations.DeleteModel(
            name='OptionValueTextES',
        ),
    ]
