# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-05-05 11:46
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0016_auto_20170505_1142'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='optionvalue',
            name='group',
        ),
        migrations.DeleteModel(
            name='GroupValue',
        ),
        migrations.DeleteModel(
            name='OptionValue',
        ),
    ]
